Processor.App.Pipeline.pipeline.ProcessorPipeline.process\_domain\_record
=========================================================================

.. currentmodule:: Processor.App.Pipeline.pipeline

.. automethod:: ProcessorPipeline.process_domain_record